Shivani Parekh has uploaded this change for review. ( https://gem5-review.googlesource.com/c/public/gem5/+/33551 )

Change subject: arch: Replaced master/slave variables isa_parser
......................................................................

arch: Replaced master/slave variables isa_parser

Change-Id: I1a4ea653cdf05aed01cb57daad6ca95a96ab1f03
---
M src/arch/isa_parser.py
1 file changed, 5 insertions(+), 5 deletions(-)



diff --git a/src/arch/isa_parser.py b/src/arch/isa_parser.py
index 8eb90ef..7d8bffd 100755
--- a/src/arch/isa_parser.py
+++ b/src/arch/isa_parser.py
@@ -1294,7 +1294,7 @@
 class SubOperandList(OperandList):
     '''Find all the operands in the given code block.  Returns an operand
     descriptor list (instance of class OperandList).'''
-    def __init__(self, parser, code, master_list):
+    def __init__(self, parser, code, requestor_list):
         self.items = []
         self.bases = {}
         # delete strings and comments so we don't match on operands inside
@@ -1315,17 +1315,17 @@
             if op_base in parser.elemToVector:
                 elem_op = op_base
                 op_base = parser.elemToVector[elem_op]
-            # find this op in the master list
-            op_desc = master_list.find_base(op_base)
+            # find this op in the requestor list
+            op_desc = requestor_list.find_base(op_base)
             if not op_desc:
-                error('Found operand %s which is not in the master list!'
+ error('Found operand %s which is not in the requestor list!'
                       % op_base)
             else:
                 # See if we've already found this operand
                 op_desc = self.find_base(op_base)
                 if not op_desc:
                     # if not, add a reference to it to this sub list
-                    self.append(master_list.bases[op_base])
+                    self.append(requestor_list.bases[op_base])

             # start next search after end of current match
             next_pos = match.end()

--
To view, visit https://gem5-review.googlesource.com/c/public/gem5/+/33551
To unsubscribe, or for help writing mail filters, visit https://gem5-review.googlesource.com/settings

Gerrit-Project: public/gem5
Gerrit-Branch: develop
Gerrit-Change-Id: I1a4ea653cdf05aed01cb57daad6ca95a96ab1f03
Gerrit-Change-Number: 33551
Gerrit-PatchSet: 1
Gerrit-Owner: Shivani Parekh <[email protected]>
Gerrit-MessageType: newchange
_______________________________________________
gem5-dev mailing list -- [email protected]
To unsubscribe send an email to [email protected]
%(web_page_url)slistinfo%(cgiext)s/%(_internal_name)s

Reply via email to